@@ -1,4 +1,4 @@
-/* $Id: benchd_sock.c,v 1.4 1999/03/02 16:38:05 roca Exp $ */
+/* $Id: benchd_sock.c,v 1.7 2000/04/27 07:01:07 roca Exp $ */
 /*
  * benchd_sock.c
  *
@@ -9,7 +9,7 @@
  *	Socket access method routines.
  */
 /*
- * (c) Copyright 1998/1999 - V. Roca (vincent.roca@lip6.fr)
+ * Copyright (c) 1998/1999 - V.Roca (vincent.roca@lip6.fr) All rights reserved
  * This tool is provided as is, without any warranty.
  * Permission to use, copy and modify is provided for non commercial
  * purposes as long as this notice appears on all copies.
@@ -34,6 +34,7 @@ SockOpen (void)
 
 		if (!(sp = getservbyname(servername, (tcp) ? "tcp" : "udp"))) {
 			PRINT_OUT((stdout, "benchd: don't know servername ""%s""\n", servername))
+			PRINT_OUT((stdout, "bench/benchd not registered in /etc/services or -p option forgotten\n"))
 			exit(1);
 		}
 		sa.sin_port = htons(sp->s_port);
@@ -134,27 +135,34 @@ SockRecvUDPMsg (void)
 			if (strcmp(recbuf, START_MSG) == 0) {
 				/* start message; reset stats and continue */
 				ResetStats();
+				PrintStartTime(0);
 				continue;
 			} else {
 				/* stop message; print stats and return */
 				fast_stop_done = 1;
 				EndStats();
+				PrintEndTime(0);
 				return;
 			}
 		}
 #endif /* FAST_SYNC */
 #define UDP_LOSS
 #ifdef UDP_LOSS
-		else if ((rdata >= sizeof(u_short)) &&
-			 (ntohs(*(u_short*)recbuf) != udp_count)) {
+		else if (rdata >= sizeof(u_short)) {
 			u_short	rec_count;	/* read from packet */
-			long	diff;		/* gap */
 
-			/* one or several UDP packets have been lost */
-			rec_count = ntohs(*(u_short*)recbuf);
-			diff = rec_count - udp_count;
-			if (diff < 0)
-				diff += (u_short)0xffff; /* counter cycle */
+			/* use memcpy first to avoid buffer alignment pbs */
+			memcpy(&rec_count, recbuf, sizeof(u_short));
+			rec_count = ntohs(rec_count);
+			if (rec_count != udp_count) {
+				/* one or several UDP packets have been lost */
+				long    diff;           /* gap */
+
+				diff = rec_count - udp_count;
+				if (diff < 0) {
+					/* counter cycle */
+					diff += (u_short)0xffff;
+				}
 #ifdef DEBUG
 				if (!(diff>=0 && diff<=(u_short)0xffff)) {
 					printf("short=%d, long=%d\n",
@@ -163,9 +171,12 @@ SockRecvUDPMsg (void)
 					sleep(0);
 				}
 #endif /* DEBUG */
-			ASSERT (diff>=0 && diff<=(u_short)0xffff)
-			udp_loss += (int)diff;
-			udp_count = rec_count + 1;
+				ASSERT (diff>=0 && diff<=(u_short)0xffff)
+				udp_loss += (int)diff;
+				udp_count = rec_count + 1;
+			} else {
+				udp_count++;
+			}
 		}
 #endif /* UDP_LOSS */
 		else {
@@ -234,8 +245,9 @@ SockRecvMsg (int	fd)
 		RecvbufMgmt (fd, SET_SOCKBUF, sock_size);
 	}
 	value = RecvbufMgmt(fd, GET_SOCKBUF, 0);
-	PRINT_OUT((stdout, "SERVER starting connection %d\n", connex))
+	/* PRINT_OUT((stdout, "SERVER starting connection %d\n", connex)) */
 	PRINT_OUT((stdout, "SERVER recv socket :\t%d bytes\n", value))
+	PrintStartTime(connex);
 
 	gettimeofday(&time0, NULL);
 	time1 = time0;
@@ -291,9 +303,12 @@ SockRecvMsg (int	fd)
 #endif /* MTRACE */
 		Stats(connex, rdata, 1, 0.0);
 	}
+	/*
 	if (!silent)
 		PRINT_OUT((stdout, "benchd: end connection %d\n", connex))
+	 */
 	EndStats();
+	PrintEndTime(connex);
 }
 
 /*
