@@ -1,4 +1,4 @@
-/* $Id: stats.c,v 1.5 1999/03/02 16:38:13 roca Exp $ */
+/* $Id: stats.c,v 1.7 1999/03/29 07:37:10 roca Exp $ */
 /*
  * stats.c
  *
@@ -8,7 +8,7 @@
  *	bench/benchd statistic routines.
  */
 /*
- * (c) Copyright 1998/1999 - V. Roca (vincent.roca@lip6.fr)
+ * Copyright (c) 1998/1999 - V.Roca (vincent.roca@lip6.fr) All rights reserved
  * This tool is provided as is, without any warranty.
  * Permission to use, copy and modify is provided for non commercial
  * purposes as long as this notice appears on all copies.
@@ -18,6 +18,44 @@
 #include "bench_proto.h"
 
 
+/****** session start/end ******/
+
+/*
+ * Print the starting and end times of each test.
+ * Can be used for synchronizing the various measurements collected
+ * on a given machine, and create a single plot.
+ */
+void
+PrintStartTime (int	conn)
+{
+	struct timeval	start;
+
+	gettimeofday(&start, NULL);
+#ifdef SERVER
+	PRINT_OUT((stdout, "SERVER %s conn %d\tstart_time=%ld.%06ld s\n",
+		provider, conn, start.tv_sec, start.tv_usec))
+#else
+	PRINT_OUT((stdout, "CLIENT %s conn %d\tstart_time=%ld.%06ld s\n",
+		provider, conn, start.tv_sec, start.tv_usec))
+#endif
+}
+
+
+void
+PrintEndTime (int	conn)
+{
+	struct timeval	end;
+
+	gettimeofday(&end, NULL);
+#ifdef SERVER
+	PRINT_OUT((stdout, "SERVER %s conn %d\tend_time=%ld.%06ld s\n",
+		provider, conn, end.tv_sec, end.tv_usec))
+#else
+	PRINT_OUT((stdout, "CLIENT %s conn %d\tend_time=%ld.%06ld s\n",
+		provider, conn, end.tv_sec, end.tv_usec))
+#endif
+}
+
 /****** statistic gathering routines ******/
 
 
@@ -30,6 +68,7 @@ ResetStats (void)
 {
 	totdata = 0;
 	totmsg = 0;
+	tottt = 0.0;		/* 17/3/99: added */
 	recdata = 0;
 	recmsg = 0;
 	rectt = 0.0;
@@ -91,7 +130,7 @@ Stats (int	conn,
 		 */
 		gettimeofday(&time2, NULL);
 		if (udp) {
-			/* XXX: very little stats available yet! */
+			/* XXX: very few stats available yet! */
 			PRINT_OUT((stdout,
 				"%ld.%06ld\tsz=%d seq=%d TT=%.3f\n",
 				time2.tv_sec, time2.tv_usec,
@@ -307,7 +346,6 @@ EndStats (void)
 			/*
 			 * throughput and RTT modes
 			 */
-
 			off = sprintf(stats, "SERVER_SUMMARY %s conn %d RCV\taverT=%s",
 				provider, connex,
 				unit_transl(fthru, TRANSL_WITH_UNITS));
