@@ -21,7 +21,7 @@
 # In case you use extensions to distinguish various bench/benchd versions...
 #BENCH_EXT='.linux'
 #BENCH_EXT='.solaris'
-BENCH_EXT='.linux'
+BENCH_EXT='.irix'
 
 # Bench repository
 BENCH_DIR="$HOME/bin/"
@@ -39,7 +39,7 @@ DIRRESULT='/tmp/net_eval/'
 # This technique is better than the one consisting in
 # limiting the number of messages!
 THRU_DURATION=20
-RTT_DURATION=120
+RTT_DURATION=10
 
 # Rate for RTT raw mode
 # Keep it small because the trace file size grows very quickly!
@@ -52,8 +52,7 @@ RATE_ARG='-rate10'
 # Edit as appropriate...
 #
 # Fast rendering: limit the number of samples.
-#LMSG='16 100 250 500 1024 2048 4096'
-LMSG='16 100 250 500 750 1024 1460'
+LMSG='16 100 250 500 1024 2048 4096'
 
 
 ###### Procedures ######
